import{t as e}from"./jsx-runtime-BHz_hoGM.js";import{t}from"./useTranslation-CWZfA4RN.js";import{O as n,P as r,Z as i}from"./main-CqHK_FoX.js";var a=e(),o=600*1e3,s=()=>{let{t:e}=t();return(0,a.jsxs)(a.Fragment,{children:[(0,a.jsx)(n,{Icon:r,title:e(`frontend.reset_cross_signing.success.heading`),success:!0}),(0,a.jsx)(i,{className:`text-center text-secondary`,size:`md`,children:e(`frontend.reset_cross_signing.success.description`,{minutes:o/(60*1e3)})})]})};export{s as component};
//# sourceMappingURL=reset-cross-signing.success-Dm0hQPEC.js.map