._browser-sessions-overview_xlk0o_8{align-items:center;gap:var(--cpd-space-4x);padding:var(--cpd-space-4x);border-radius:var(--cpd-space-3x);background-color:var(--cpd-color-bg-canvas-default);outline:1px solid var(--cpd-color-gray-400);outline-offset:-1px;display:flex}
