import{t as e}from"./jsx-runtime-BHz_hoGM.js";import{t}from"./useTranslation-CWZfA4RN.js";import{D as n,J as r,m as i}from"./main-CqHK_FoX.js";import{t as a}from"./Link-CRQHm-_P.js";var o=e();function s(){let{id:e}=i.useParams(),{t:s}=t();return(0,o.jsx)(n,{children:(0,o.jsxs)(r,{type:`critical`,title:s(`frontend.session_detail.alert.title`,{deviceId:e}),children:[s(`frontend.session_detail.alert.text`),(0,o.jsx)(a,{to:`/sessions`,children:s(`frontend.session_detail.alert.button`)})]})})}export{s as notFoundComponent};
//# sourceMappingURL=sessions._id-D8lY0ot4.js.map