._nav-bar_16kbp_8{border-bottom:var(--cpd-border-width-1) solid var(--cpd-color-gray-400)}._nav-bar-items_16kbp_12{justify-content:flex-start;align-items:center;gap:var(--cpd-space-3x);flex-direction:row;display:flex}._nav-tab_12e0b_8{padding:var(--cpd-space-4x) 0;position:relative}._nav-tab_12e0b_8:before{content:"";border-radius:var(--cpd-radius-pill-effect) var(--cpd-radius-pill-effect) 0 0;background-color:var(--cpd-color-bg-action-primary-rest);height:0;transition:height .1s ease-in-out;position:absolute;bottom:0;left:0;right:0}._nav-tab_12e0b_8:has(._nav-item_12e0b_26[aria-current=page]):before{height:var(--cpd-border-width-4)}._nav-item_12e0b_26{align-items:center;gap:var(--cpd-space-1x);padding:var(--cpd-space-1x) var(--cpd-space-2x);color:var(--cpd-color-text-secondary);line-height:var(--cpd-space-6x);border-radius:var(--cpd-radius-pill-effect);border:transparent var(--cpd-border-width-2) solid;display:flex}._nav-item_12e0b_26._external-link_12e0b_43{color:var(--cpd-color-text-primary);text-decoration:underline}._nav-item_12e0b_26:hover{color:var(--cpd-color-text-primary);background-color:var(--cpd-color-bg-subtle-secondary)}._nav-item_12e0b_26:active{color:var(--cpd-color-text-primary);background-color:var(--cpd-color-bg-subtle-primary)}._nav-item_12e0b_26:focus{border-color:var(--cpd-color-border-focused);outline:none}._nav-item_12e0b_26[aria-current=page]{color:var(--cpd-color-text-primary)}._nav-bar-error-icon_12e0b_67{color:var(--cpd-color-icon-critical-primary);display:inline-block}._user_lnqhg_8{align-items:center;gap:var(--cpd-space-4x);outline:1px solid var(--cpd-color-gray-400);outline-offset:-1px;border-radius:var(--cpd-space-3x);padding:var(--cpd-space-4x);flex-direction:row;display:flex}._meta_lnqhg_19{flex:1;min-width:0}._meta_lnqhg_19 p{white-space:nowrap;text-overflow:ellipsis;overflow:hidden}._edit-button_lnqhg_32{align-self:flex-start}._mxid_lnqhg_36{color:var(--cpd-color-text-secondary)}._dialog-form_lnqhg_40{gap:var(--cpd-space-4x);width:100%;max-width:378px;flex-direction:column;align-self:center;margin-block-end:var(--cpd-space-9x);display:flex}
