import{t as e}from"./jsx-runtime-BHz_hoGM.js";import{t}from"./useTranslation-CWZfA4RN.js";import{D as n,O as r,P as i}from"./main-CqHK_FoX.js";import{t as a}from"./ButtonLink-BaIKz4k4.js";var o=e();function s(){let{t:e}=t();return(0,o.jsx)(n,{children:(0,o.jsxs)(`div`,{className:`flex flex-col gap-10`,children:[(0,o.jsx)(r,{Icon:i,title:e(`frontend.password_change.success.title`),subtitle:e(`frontend.password_change.success.description`),success:!0}),(0,o.jsx)(a,{to:`/`,kind:`tertiary`,children:e(`action.back`)})]})})}export{s as component};
//# sourceMappingURL=password.change.success-D9T29Rcb.js.map