{#
Copyright 2025, 2026 Element Creations Ltd.
Copyright 2025 New Vector Ltd.

SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-Element-Commercial
Please see LICENSE files in the repository root for full details.
-#}

{% extends "base.html" %}

{% block content %}
  <main class="flex flex-col gap-6">
    <header class="page-heading">
      <div class="icon invalid">
        {{ icon.leave() }}
      </div>

      <div class="header">
        <h1 class="title">{{ _("mas.account.logged_out.heading") }}</h1>
        <p class="text">{{ _("mas.account.logged_out.description") }}</p>
      </div>

      {{ logout.button(text=_("action.sign_out"), csrf_token=csrf_token, post_logout_action=post_logout_action|default({})) }}
    </header>
  </main>
{% endblock %}
