import{t as e}from"./jsx-runtime-BHz_hoGM.js";import{$ as t,D as n}from"./main-CqHK_FoX.js";var r=e(),i=()=>(0,r.jsx)(n,{children:(0,r.jsx)(t,{})});export{i as component};
//# sourceMappingURL=reset-cross-signing-NZa0DJxI.js.map