import{n as e}from"./rolldown-runtime-Bh1tDfsg.js";import{n as t,t as n}from"./jsx-runtime-BHz_hoGM.js";var r=e(t(),1),i=n(),a=(0,r.forwardRef)(function({as:e,children:t,className:n,disabled:r,...a},o){let s=e||`button`,{onClick:c,onSubmit:l,onPointerDown:u,onPointerUp:d,onKeyDown:f,onKeyUp:p,onKeyPress:m,...h}=a,g=r?{}:{onClick:c,onSubmit:l,onPointerDown:u,onPointerUp:d,onKeyDown:f,onKeyUp:p,onKeyPress:m};return(0,i.jsx)(s,{ref:o,className:n,role:e===`a`?`link`:`button`,tabIndex:0,"aria-disabled":r,...h,...g,children:t})});export{a as t};
//# sourceMappingURL=UnstyledButton-DUlWjjo6.js.map