import{n as e}from"./rolldown-runtime-Bh1tDfsg.js";import{s as t}from"./graphql-w47gyQE9.js";import{n,t as r}from"./jsx-runtime-BHz_hoGM.js";import{t as i}from"./useNavigate-_c9R0sfE.js";import{o as a}from"./main-CqHK_FoX.js";var o=e(n()),s=r();function c(){let{planManagementIframeUri:e}=t(a).data.siteConfig;return e?(0,s.jsx)(l,{planManagementIframeUri:e}):(0,s.jsx)(i,{to:`/`,replace:!0})}function l({planManagementIframeUri:e}){let t=(0,o.useRef)(null),n=(0,o.useCallback)(()=>{let e=t.current;if(!e)return;let n=e.contentWindow?.document.body.parentElement?.scrollHeight;n?e.height=`${n}px`:e.height=`500px`},[]),r=(0,o.useMemo)(()=>new MutationObserver(e=>{n(),setTimeout(()=>{n()},1e3)}),[n]),i=(0,o.useCallback)(e=>{let t=e.contentWindow?.document.body;t&&(n(),r.observe(t,{childList:!0,subtree:!0,attributes:!0}))},[n,r]);return(0,o.useEffect)(()=>{let e=t.current;return e&&i(e),()=>r.disconnect()},[r,i]),(0,s.jsx)(`iframe`,{title:`iframe`,ref:t,onLoad:e=>i(e.target),src:e,scrolling:`no`})}export{c as component};
//# sourceMappingURL=_account.plan.index-D5DI7oP0.js.map