@keyframes _spin_a0mwm_1{to{transform:rotate(360deg)}}:root{--size:var(--cpd-space-16x)}._inline_a0mwm_18{margin-right:var(--cpd-space-4x);display:inline}._inline_a0mwm_18 ._loading-spinner-inner_a0mwm_22{height:var(--cpd-space-4x);width:var(--cpd-space-4x)}._mini_a0mwm_28{margin-right:var(--cpd-space-4x)}._mini_a0mwm_28 ._loading-spinner-inner_a0mwm_22{height:var(--cpd-space-8x);width:var(--cpd-space-8x)}._loading-spinner-inner_a0mwm_22{height:var(--cpd-space-16x);width:var(--cpd-space-16x);fill:var(--cpd-color-icon-primary);animation:1s linear infinite _spin_a0mwm_1;display:inline}
