{#
Copyright 2024, 2025 New Vector Ltd.
Copyright 2024 The Matrix.org Foundation C.I.C.

SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-Element-Commercial
Please see LICENSE files in the repository root for full details.
-#}

{% extends "base.html" %}

{% block content %}
  <header class="page-heading">
    <div class="icon invalid">
      {{ icon.error_solid() }}
    </div>

    <div class="header">
      <h1 class="title">{{ _("mas.recovery.consumed.heading") }}</h1>
      <p class="text">{{ _("mas.recovery.consumed.description") }}</p>
    </div>

    {{ button.link_outline(text=_("action.start_over"), href="/login") }}
  </header>
{% endblock content %}
