._header_1crjt_8{justify-content:flex-start;gap:var(--cpd-space-4x);flex-direction:row;align-items:center;display:flex}._back-button_1crjt_16{inline-size:var(--cpd-space-7x);block-size:var(--cpd-space-7x);padding:var(--cpd-space-1x);aspect-ratio:1;color:var(--cpd-color-icon-tertiary);appearance:none;cursor:pointer;background-color:var(--cpd-color-bg-subtle-secondary);border:0;border-radius:50%;line-height:0;display:block;position:relative}._back-button_1crjt_16 svg{inline-size:var(--cpd-space-5x);block-size:var(--cpd-space-5x)}._back-button_1crjt_16[aria-disabled=true]{color:var(--cpd-color-icon-disabled);cursor:not-allowed}@media (hover){._back-button_1crjt_16:not([aria-disabled=true]):hover{color:var(--cpd-color-icon-primary);background:var(--cpd-color-bg-subtle-primary)}}._back-button_1crjt_16:not([aria-disabled=true]):active{color:var(--cpd-color-icon-primary);background:var(--cpd-color-bg-subtle-primary)}
