{#
Copyright 2024, 2025 New Vector Ltd.
Copyright 2021-2024 The Matrix.org Foundation C.I.C.

SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-Element-Commercial
Please see LICENSE files in the repository root for full details.
-#}

{# Sometimes we don't have the language set, so we default to english #}
{% set lang = lang or "en" %}

{% extends "base.html" %}

{% block content %}
  <main class="flex flex-col gap-6">
    <header class="page-heading">
      <div class="icon invalid">
        {{ icon.error_solid() }}
      </div>

      <div class="header">
        <h1 class="title">{{ _("error.unexpected") }}</h1>
        {% if code %}
          <p class="text font-semibold font-mono">
            {{ code }}
          </p>
        {% endif %}
        {% if description %}
          <p class="text">
            {{ description }}
          </p>
        {% endif %}
      </div>
    </header>

    {% if details %}
      <hr />
      {# caution: do not introduce whitespace between <pre> and <code> #}
      <pre><code class="font-mono whitespace-pre-wrap break-all">{{ details }}</code></pre>
    {% endif %}
  </main>
{% endblock %}
