{#
Copyright 2024, 2025 New Vector Ltd.
Copyright 2023, 2024 The Matrix.org Foundation C.I.C.

SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-Element-Commercial
Please see LICENSE files in the repository root for full details.
-#}

<footer class="legal-footer">
  {%- if branding.policy_uri is not none or branding.tos_uri is not none -%}
    <nav>
      {%- if branding.policy_uri is not none -%}
        <a href="{{ branding.policy_uri }}" referrerpolicy="no-referrer" title="{{ _('branding.privacy_policy.alt') }}" class="cpd-link" data-kind="primary">
          {{- _("branding.privacy_policy.link") -}}
        </a>
      {%- endif -%}

      {%- if branding.policy_uri is not none and branding.tos_uri is not none -%}
        <div class="separator" aria-hidden="true">•</div>
      {%- endif -%}

      {%- if branding.tos_uri is not none -%}
        <a href="{{ branding.tos_uri }}" referrerpolicy="no-referrer" title="{{ _('branding.terms_and_conditions.alt') }}" class="cpd-link" data-kind="primary">
          {{- _("branding.terms_and_conditions.link") -}}
        </a>
      {%- endif -%}
    </nav>
  {%- endif -%}

  {%- if branding.imprint is not none -%}
    <p class="imprint">{{ branding.imprint }}</p>
  {%- endif -%}
</footer>
