{#
Copyright 2024, 2025 New Vector Ltd.
Copyright 2022-2024 The Matrix.org Foundation C.I.C.

SPDX-License-Identifier: AGPL-3.0-only OR LicenseRef-Element-Commercial
Please see LICENSE files in the repository root for full details.
-#}

{% extends "base.html" %}

{% block content %}
  <header class="page-heading">
    <div class="icon">
      {{ icon.link() }}
    </div>

    <div class="header">
      <h1 class="title">{{ _("mas.upstream_oauth2.suggest_link.heading") }}</h1>
    </div>
  </header>

  <section class="flex flex-col gap-6 justify-center">
    <form method="POST" class="cpd-form-root">
      <input type="hidden" name="csrf" value="{{ csrf_token }}" />
      <input type="hidden" name="action" value="link" />

      {{ button.button(text=_("mas.upstream_oauth2.suggest_link.action")) }}
    </form>

    {{ field.separator() }}

    {{ logout.button(text=_("action.sign_out"), csrf_token=csrf_token, post_logout_action=post_logout_action) }}
  </section>
{% endblock content %}
